YARP 2.3.21 (2013-07-08)                                              {#v2_3_21}
========================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.20...v2.3.21`):

```
   308	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
   137	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    70	Ali Paikan <ali.paikan@iit.it>
    35	Elena Ceseracciu <elena.ceseracciu@iit.it>
    14	Alberto Cardellino <alberto.cardellino@iit.it>
    13	Matteo Brunettini <matteo.brunettini@iit.it>
    12	Lorenzo Natale <lorenzo.natale@iit.it>
    11	Alessandro Scalzo <alessandro.scalzo@iit.it>
    11	Ugo Pattacini <ugo.pattacini@iit.it>
     3	Marco Randazzo <marco.randazzo@iit.it>
     1	Valentina Gaggero <valentina.gaggero@iit.it>
```
